@@ -6,14 +6,14 @@ use std::{
 
 use crate::{body::Body, fragment::Fragment};
 
-/// The `Subject` from the `CommitMessage`
+/// The [`Subject`] from the [`CommitMessage`]
 #[derive(Debug, PartialEq, Clone, Default)]
 pub struct Subject {
     text: String,
 }
 
 impl Subject {
-    /// Count characters in `Subject`
+    /// Count characters in [`Subject`]
     ///
     /// # Examples
     ///
@@ -28,7 +28,7 @@ impl Subject {
         self.text.len()
     }
 
-    /// Is the `Subject` empty
+    /// Is the [`Subject`] empty
     ///
     /// # Examples
     ///
@@ -43,7 +43,7 @@ impl Subject {
         self.text.is_empty()
     }
 
-    /// Convert the `Subject` into chars
+    /// Convert the [`Subject`] into chars
     ///
     /// # Examples
     ///
@@ -67,7 +67,7 @@ impl Subject {
 
 impl From<&str> for Subject {
     fn from(subject: &str) -> Self {
-        Subject {
+        Self {
             text: subject.into(),
         }
     }
@@ -75,12 +75,12 @@ impl From<&str> for Subject {
 
 impl From<String> for Subject {
     fn from(subject: String) -> Self {
-        Subject { text: subject }
+        Self { text: subject }
     }
 }
 
 impl From<Subject> for String {
-    fn from(subject: Subject) -> String {
+    fn from(subject: Subject) -> Self {
         subject.text
     }
 }
@@ -92,8 +92,8 @@ impl Display for Subject {
 }
 
 impl From<Body> for Subject {
-    fn from(body: Body) -> Subject {
-        Subject::from(String::from(body))
+    fn from(body: Body) -> Self {
+        Self::from(String::from(body))
     }
 }
 
@@ -102,7 +102,7 @@ impl From<Vec<Fragment>> for Subject {
         ast.iter()
             .find_map(|values| {
                 if let Fragment::Body(body) = values {
-                    Some(Subject::from(body.clone()))
+                    Some(Self::from(body.clone()))
                 } else {
                     None
                 }
